/*  Glimmer - getprefs.h
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _GETPREFS_H_
#define _GETPREFS_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"

void get_prefs(void);
void save_prefs(void);
void save_defaults(void);
void save_session_pref(void);
void build_defaults(void);

void get_saved_colors(void);
void save_colors(void);
void save_default_colors(void);
void build_default_colors(void);

void save_directory_history(GList *history, gchar *name);
void get_directory_history(GList **history, gchar *name);

#ifdef __cplusplus
}
#endif

#endif
